==> qgis_3.10.14+dfsg.orig.tar.xz: qgis-3.10.14/src/gui/qgsattributeformlegacyinterface.h <==
/***************************************************************************
    qgsattributeformlegacyinterface.h
     --------------------------------------
    Date                 : 13.5.2014
    Copyright            : (C) 2014 Matthias Kuhn
    Email                : matthias at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSATTRIBUTEFORMLEGACYINTERFACE_H
#define QGSATTRIBUTEFORMLEGACYINTERFACE_H

#include <QString>

#include "qgsattributeforminterface.h"
#include "qgis_gui.h"

#define SIP_NO_FILE

/**
 * \ingroup gui
 * This class helps to support legacy open form scripts to be compatible with the new
 * QgsAttributeForm style interface.
 * \note not available in Python bindings
 */
class GUI_EXPORT QgsAttributeFormLegacyInterface : public QgsAttributeFormInterface
{
  public:
    explicit QgsAttributeFormLegacyInterface( const QString &function, const QString &pyFormName, QgsAttributeForm *form );
    ~QgsAttributeFormLegacyInterface() override;

    // QgsAttributeFormInterface interface
    void featureChanged() override;

  private:
    QString mPyFunctionName;
    QString mPyFormVarName;
    QString mPyLayerVarName;
};

#endif // QGSATTRIBUTEFORMLEGACYINTERFACE_H

==> qgis_3.40.12+dfsg.orig.tar.xz: qgis-3.40.12/src/gui/qgsattributeformlegacyinterface.h <==
/***************************************************************************
    qgsattributeformlegacyinterface.h
     --------------------------------------
    Date                 : 13.5.2014
    Copyright            : (C) 2014 Matthias Kuhn
    Email                : matthias at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSATTRIBUTEFORMLEGACYINTERFACE_H
#define QGSATTRIBUTEFORMLEGACYINTERFACE_H

#include <QString>

#include "qgsattributeforminterface.h"
#include "qgis_gui.h"

#define SIP_NO_FILE

/**
 * \ingroup gui
 * \brief This class helps to support legacy open form scripts to be compatible with the new
 * QgsAttributeForm style interface.
 * \note not available in Python bindings
 */
class GUI_EXPORT QgsAttributeFormLegacyInterface : public QgsAttributeFormInterface
{
  public:
    explicit QgsAttributeFormLegacyInterface( const QString &function, const QString &pyFormName, QgsAttributeForm *form );
    ~QgsAttributeFormLegacyInterface() override;

    // QgsAttributeFormInterface interface
    void featureChanged() override;

  private:
    QString mPyFunctionName;
    QString mPyFormVarName;
    QString mPyLayerVarName;
};

#endif // QGSATTRIBUTEFORMLEGACYINTERFACE_H
